/*
 *    simon@schoar.de GPL
 */

#include "local.c"

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>

const uint8_t SEQ[] = { H, W, H, L };

void play(uint16_t led, uint16_t pos, uint16_t wait) {
    SERVO = pos;
    
    int i=0;
    for (; i < SERVO_WAIT_MULTIPLIER; i++) {
	if (i == SERVO_WAIT_MULTIPLIER_LED_TOGGLE) {
	    PORTD |= _BV(led);
	}
	_delay_ms(wait);
    }
    
    SERVO = SERVO_CENTER;
    
    for (; i > 0; i--) {
	if (i == SERVO_WAIT_MULTIPLIER_LED_TOGGLE) {
	    PORTD &= ~_BV(led);
	}
    _delay_ms(wait);
    }
}

void ring() {
    int i = 0;
    for (; i < sizeof(SEQ); i++) {
	if (SEQ[i] == W) {
	    _delay_ms(WAIT_PERIOD);
	}
	if (SEQ[i] == H) {
	    play(LED_HIGH, SERVO_HIGH, SERVO_HIGH_WAIT);
	}
	if (SEQ[i] == L) {
	    play(LED_LOW, SERVO_LOW, SERVO_LOW_WAIT);
	}
    }
}

ISR(INT1_vect) {
    ring();
}


int main (void) {
    DDRB = 0x00;
    DDRC = 0x00;
    DDRD = 0x00;

    // prepare LEDs
    DDRD |= _BV(LED_HIGH) | _BV(LED_LOW);
    PORTD &= ~(_BV(LED_HIGH) | _BV(LED_LOW));

    // INT1 - test button
    MCUCR |= (1<<ISC11) | (1<<ISC10);
    GICR |= (1<<INT1);

    // servo pwm
    TCCR1A = _BV(COM1A1);		// Clear OC1A/OC1B on Compare Match, output low
    TCCR1B = _BV(WGM13) |_BV(CS11);	// PWM, Phase and Frequency Correct, ICR1, Bottom, clk/8
    ICR1 = 0x2710;
    
    TIMSK |= (1<<TOIE1);
    SERVO = SERVO_CENTER;
    DDRB |= _BV(PB1);

    sei();
    
    return (0);
}
